const { Client, Intents } = require('discord.js');
const { token, clientId } = require('./config.json');

const CommandParser = require('./commands/CommandParser.js');
const complotDB = require('./database/ComplotDB.js');
const VoteParser = require('./vote/VoteParser');

const client = new Client({ intents: [Intents.FLAGS.GUILDS, Intents.FLAGS.GUILD_MESSAGES, Intents.FLAGS.GUILD_MESSAGE_REACTIONS],
	partials: ['MESSAGE', 'CHANNEL', 'REACTION'] });

let parser = null;
let voteParser = null;

client.once('ready', () => {
	voteParser = new VoteParser(client);
	parser = new CommandParser(client, voteParser);
    console.log('Ready!');
    
});



client.on("messageCreate", (message)=>{
    if(!parser) return;
    if(message.author.id !== clientId){
        parser.parse(message);
    }
});

client.on('messageReactionAdd', async (reaction, user) => {
	if (reaction.partial) {
		try {
			await reaction.fetch();
		} catch (error) {
			console.error('Something went wrong when fetching the message:', error);
			return;
		}
	}
	voteParser.parse(reaction.message);
});
client.login(token);
